Learn R Programming

saqgetr (version 0.2.21)

get_saq_simple_summaries: Function to get simple summaries of air quality observations.

Description

Function to get simple summaries of air quality observations.

Usage

get_saq_simple_summaries(file = NA, summary = "annual_means", tz = "UTC")

Arguments

file

File of simple summaries table.

summary

Summary period to import. Can either be "annual_means" or "monthly_means".

tz

Time zone for the observations' dates.

Value

Tibble.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
# Import annual means
data_annual <- get_saq_simple_summaries(summary = "annual_means")

# }
# NOT RUN {
# }
# NOT RUN {
# Import monthly means, quite a large request so will take some time
data_month <- get_saq_simple_summaries(summary = "monthly_means")

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab